@@ -4,6 +4,7 @@ from .align import AlignMethod
 from .cells import cell_len, set_cell_size
 from .console import Console, ConsoleOptions, RenderResult
 from .jupyter import JupyterMixin
+from .measure import Measurement
 from .style import Style
 from .text import Text
 
@@ -15,7 +16,7 @@ class Rule(JupyterMixin):
         title (Union[str, Text], optional): Text to render in the rule. Defaults to "".
         characters (str, optional): Character(s) used to draw the line. Defaults to "─".
         style (StyleType, optional): Style of Rule. Defaults to "rule.line".
-        end (str, optional): Character at end of Rule. defaults to "\\n"
+        end (str, optional): Character at end of Rule. defaults to "\\\\n"
         align (str, optional): How to align the title, one of "left", "center", or "right". Defaults to "center".
     """
 
@@ -62,10 +63,7 @@ class Rule(JupyterMixin):
 
         chars_len = cell_len(characters)
         if not self.title:
-            rule_text = Text(characters * ((width // chars_len) + 1), self.style)
-            rule_text.truncate(width)
-            rule_text.plain = set_cell_size(rule_text.plain, width)
-            yield rule_text
+            yield self._rule_line(chars_len, width)
             return
 
         if isinstance(self.title, Text):
@@ -75,10 +73,16 @@ class Rule(JupyterMixin):
 
         title_text.plain = title_text.plain.replace("\n", " ")
         title_text.expand_tabs()
-        rule_text = Text(end=self.end)
 
+        required_space = 4 if self.align == "center" else 2
+        truncate_width = max(0, width - required_space)
+        if not truncate_width:
+            yield self._rule_line(chars_len, width)
+            return
+
+        rule_text = Text(end=self.end)
         if self.align == "center":
-            title_text.truncate(width - 4, overflow="ellipsis")
+            title_text.truncate(truncate_width, overflow="ellipsis")
             side_width = (width - cell_len(title_text.plain)) // 2
             left = Text(characters * (side_width // chars_len + 1))
             left.truncate(side_width - 1)
@@ -89,12 +93,12 @@ class Rule(JupyterMixin):
             rule_text.append(title_text)
             rule_text.append(" " + right.plain, self.style)
         elif self.align == "left":
-            title_text.truncate(width - 2, overflow="ellipsis")
+            title_text.truncate(truncate_width, overflow="ellipsis")
             rule_text.append(title_text)
             rule_text.append(" ")
             rule_text.append(characters * (width - rule_text.cell_len), self.style)
         elif self.align == "right":
-            title_text.truncate(width - 2, overflow="ellipsis")
+            title_text.truncate(truncate_width, overflow="ellipsis")
             rule_text.append(characters * (width - title_text.cell_len - 1), self.style)
             rule_text.append(" ")
             rule_text.append(title_text)
@@ -102,14 +106,29 @@ class Rule(JupyterMixin):
         rule_text.plain = set_cell_size(rule_text.plain, width)
         yield rule_text
 
+    def _rule_line(self, chars_len: int, width: int) -> Text:
+        rule_text = Text(self.characters * ((width // chars_len) + 1), self.style)
+        rule_text.truncate(width)
+        rule_text.plain = set_cell_size(rule_text.plain, width)
+        return rule_text
+
+    def __rich_measure__(
+        self, console: Console, options: ConsoleOptions
+    ) -> Measurement:
+        return Measurement(1, 1)
+
 
 if __name__ == "__main__":  # pragma: no cover
-    from rich.console import Console
     import sys
 
+    from rich.console import Console
+
     try:
         text = sys.argv[1]
     except IndexError:
         text = "Hello, World"
     console = Console()
     console.print(Rule(title=text))
+
+    console = Console()
+    console.print(Rule("foo"), width=4)
